@Generated public enum RuntimeEngine extends Enum<RuntimeEngine>
This field is not compatible with legacy `spark_version` values that contain `-photon-`. Remove `-photon-` from the `spark_version` and set `runtime_engine` to `PHOTON`.
If left unspecified, the runtime engine defaults to standard unless the spark_version contains -photon-, in which case Photon will be used.
| Modifier and Type | Method and Description |
|---|---|
static RuntimeEngine |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static RuntimeEngine[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final RuntimeEngine NULL
public static final RuntimeEngine PHOTON
public static final RuntimeEngine STANDARD
public static RuntimeEngine[] values()
for (RuntimeEngine c : RuntimeEngine.values()) System.out.println(c);
public static RuntimeEngine valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025. All rights reserved.