@Generated public enum CdfState extends Enum<CdfState>
| Enum Constant and Description |
|---|
CDF_STATE_SKIPPED |
CDF_STATE_SNAPSHOTTING |
CDF_STATE_STREAMING |
CDF_STATE_TERMINATED |
| Modifier and Type | Method and Description |
|---|---|
static CdfState |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static CdfState[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CdfState CDF_STATE_SKIPPED
public static final CdfState CDF_STATE_SNAPSHOTTING
public static final CdfState CDF_STATE_STREAMING
public static final CdfState CDF_STATE_TERMINATED
public static CdfState[] values()
for (CdfState c : CdfState.values()) System.out.println(c);
public static CdfState valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2026. All rights reserved.