@Generated public class AccountSettingsAPI extends Object
| Constructor and Description |
|---|
AccountSettingsAPI(AccountSettingsService mock)
Constructor for mocks
|
AccountSettingsAPI(ApiClient apiClient)
Regular-use constructor
|
| Modifier and Type | Method and Description |
|---|---|
CspEnablementAccountAPI |
CspEnablementAccount()
The compliance security profile settings at the account level control whether to enable it for
new workspaces.
|
DisableLegacyFeaturesAPI |
DisableLegacyFeatures()
Disable legacy features for new Databricks workspaces.
|
EnableIpAccessListsAPI |
EnableIpAccessLists()
Controls the enforcement of IP access lists for accessing the account console.
|
EsmEnablementAccountAPI |
EsmEnablementAccount()
The enhanced security monitoring setting at the account level controls whether to enable the
feature on new workspaces.
|
AccountSettingsService |
impl() |
PersonalComputeAPI |
PersonalCompute()
The Personal Compute enablement setting lets you control which users can use the Personal
Compute default policy to create compute resources.
|
public AccountSettingsAPI(ApiClient apiClient)
public AccountSettingsAPI(AccountSettingsService mock)
public CspEnablementAccountAPI CspEnablementAccount()
public DisableLegacyFeaturesAPI DisableLegacyFeatures()
public EnableIpAccessListsAPI EnableIpAccessLists()
public EsmEnablementAccountAPI EsmEnablementAccount()
public PersonalComputeAPI PersonalCompute()
public AccountSettingsService impl()
Copyright © 2025. All rights reserved.