@Generated public class SettingsAPI extends Object
| Constructor and Description |
|---|
SettingsAPI(ApiClient apiClient)
Regular-use constructor
|
SettingsAPI(SettingsService mock)
Constructor for mocks
|
| Modifier and Type | Method and Description |
|---|---|
AibiDashboardEmbeddingAccessPolicyAPI |
AibiDashboardEmbeddingAccessPolicy()
Controls whether AI/BI published dashboard embedding is enabled, conditionally enabled, or
disabled at the workspace level.
|
AibiDashboardEmbeddingApprovedDomainsAPI |
AibiDashboardEmbeddingApprovedDomains()
Controls the list of domains approved to host the embedded AI/BI dashboards.
|
AutomaticClusterUpdateAPI |
AutomaticClusterUpdate()
Controls whether automatic cluster update is enabled for the current workspace.
|
ComplianceSecurityProfileAPI |
ComplianceSecurityProfile()
Controls whether to enable the compliance security profile for the current workspace.
|
DefaultNamespaceAPI |
DefaultNamespace()
The default namespace setting API allows users to configure the default namespace for a
Databricks workspace.
|
DisableLegacyAccessAPI |
DisableLegacyAccess()
'Disabling legacy access' has the following impacts: 1.
|
DisableLegacyDbfsAPI |
DisableLegacyDbfs()
When this setting is on, access to DBFS root and DBFS mounts is disallowed (as well as creation
of new mounts).
|
EnhancedSecurityMonitoringAPI |
EnhancedSecurityMonitoring()
Controls whether enhanced security monitoring is enabled for the current workspace.
|
SettingsService |
impl() |
RestrictWorkspaceAdminsAPI |
RestrictWorkspaceAdmins()
The Restrict Workspace Admins setting lets you control the capabilities of workspace admins.
|
public SettingsAPI(ApiClient apiClient)
public SettingsAPI(SettingsService mock)
public AibiDashboardEmbeddingAccessPolicyAPI AibiDashboardEmbeddingAccessPolicy()
public AibiDashboardEmbeddingApprovedDomainsAPI AibiDashboardEmbeddingApprovedDomains()
public AutomaticClusterUpdateAPI AutomaticClusterUpdate()
public ComplianceSecurityProfileAPI ComplianceSecurityProfile()
public DefaultNamespaceAPI DefaultNamespace()
public DisableLegacyAccessAPI DisableLegacyAccess()
public DisableLegacyDbfsAPI DisableLegacyDbfs()
public EnhancedSecurityMonitoringAPI EnhancedSecurityMonitoring()
public RestrictWorkspaceAdminsAPI RestrictWorkspaceAdmins()
public SettingsService impl()
Copyright © 2025. All rights reserved.