| Interface | Description |
|---|---|
| AlertsLegacyService |
The alerts API can be used to perform CRUD operations on alerts.
|
| AlertsService |
The alerts API can be used to perform CRUD operations on alerts.
|
| DashboardsService |
In general, there is little need to modify dashboards using the API.
|
| DashboardWidgetsService |
This is an evolving API that facilitates the addition and removal of widgets from existing
dashboards within the Databricks Workspace.
|
| DataSourcesService |
This API is provided to assist you in making new query objects.
|
| DbsqlPermissionsService |
The SQL Permissions API is similar to the endpoints of the :method:permissions/set.
|
| QueriesLegacyService |
These endpoints are used for CRUD operations on query definitions.
|
| QueriesService |
The queries API can be used to perform CRUD operations on queries.
|
| QueryHistoryService |
A service responsible for storing and retrieving the list of queries run against SQL endpoints
and serverless compute.
|
| QueryVisualizationsLegacyService |
This is an evolving API that facilitates the addition and removal of vizualisations from existing
queries within the Databricks Workspace.
|
| QueryVisualizationsService |
This is an evolving API that facilitates the addition and removal of visualizations from existing
queries in the Databricks Workspace.
|
| RedashConfigService |
Redash V2 service for workspace configurations (internal)
|
| StatementExecutionService |
The Databricks SQL Statement Execution API can be used to execute SQL statements on a SQL
warehouse and fetch the result.
|
| WarehousesService |
A SQL warehouse is a compute resource that lets you run SQL commands on data objects within
Databricks SQL.
|
| Class | Description |
|---|---|
| AccessControl | |
| Alert | |
| AlertCondition | |
| AlertConditionOperand | |
| AlertConditionThreshold | |
| AlertOperandColumn | |
| AlertOperandValue | |
| AlertOptions |
Alert configuration options.
|
| AlertQuery | |
| AlertsAPI |
The alerts API can be used to perform CRUD operations on alerts.
|
| AlertsLegacyAPI |
The alerts API can be used to perform CRUD operations on alerts.
|
| BaseChunkInfo |
Describes metadata for a particular chunk, within a result set; this structure is used both
within a manifest, and when fetching individual chunk data or links.
|
| CancelExecutionRequest |
Cancel statement execution
|
| CancelExecutionResponse | |
| Channel |
Configures the channel name and DBSQL version of the warehouse.
|
| ChannelInfo |
Details about a Channel.
|
| ClientConfig | |
| ColumnInfo | |
| CreateAlert | |
| CreateAlertRequest | |
| CreateAlertRequestAlert | |
| CreateQueryRequest | |
| CreateQueryRequestQuery | |
| CreateQueryVisualizationsLegacyRequest |
Add visualization to a query
|
| CreateVisualizationRequest | |
| CreateVisualizationRequestVisualization | |
| CreateWarehouseRequest | |
| CreateWarehouseResponse | |
| CreateWidget | |
| Dashboard |
A JSON representing a dashboard containing widgets of visualizations and text boxes.
|
| DashboardEditContent | |
| DashboardOptions | |
| DashboardPostContent | |
| DashboardsAPI |
In general, there is little need to modify dashboards using the API.
|
| DashboardWidgetsAPI |
This is an evolving API that facilitates the addition and removal of widgets from existing
dashboards within the Databricks Workspace.
|
| DataSource |
A JSON object representing a DBSQL data source / SQL warehouse.
|
| DataSourcesAPI |
This API is provided to assist you in making new query objects.
|
| DateRange | |
| DateRangeValue | |
| DateValue | |
| DbsqlPermissionsAPI |
The SQL Permissions API is similar to the endpoints of the :method:permissions/set.
|
| DeleteAlertsLegacyRequest |
Delete an alert
|
| DeleteDashboardRequest |
Remove a dashboard
|
| DeleteDashboardWidgetRequest |
Remove widget
|
| DeleteQueriesLegacyRequest |
Delete a query
|
| DeleteQueryVisualizationsLegacyRequest |
Remove visualization
|
| DeleteResponse | |
| DeleteVisualizationRequest |
Remove a visualization
|
| DeleteWarehouseRequest |
Delete a warehouse
|
| DeleteWarehouseResponse | |
| EditAlert | |
| EditWarehouseRequest | |
| EditWarehouseResponse | |
| Empty |
Represents an empty message, similar to google.protobuf.Empty, which is not available in the firm
right now.
|
| EndpointConfPair | |
| EndpointHealth | |
| EndpointInfo | |
| EndpointTagPair | |
| EndpointTags | |
| EnumValue | |
| ExecuteStatementRequest | |
| ExternalLink | |
| GetAlertRequest |
Get an alert
|
| GetAlertsLegacyRequest |
Get an alert
|
| GetDashboardRequest |
Retrieve a definition
|
| GetDbsqlPermissionRequest |
Get object ACL
|
| GetQueriesLegacyRequest |
Get a query definition.
|
| GetQueryRequest |
Get a query
|
| GetResponse | |
| GetStatementRequest |
Get status, manifest, and result first chunk
|
| GetStatementResultChunkNRequest |
Get result chunk by index
|
| GetWarehousePermissionLevelsRequest |
Get SQL warehouse permission levels
|
| GetWarehousePermissionLevelsResponse | |
| GetWarehousePermissionsRequest |
Get SQL warehouse permissions
|
| GetWarehouseRequest |
Get warehouse info
|
| GetWarehouseResponse | |
| GetWorkspaceWarehouseConfigResponse | |
| LegacyAlert | |
| LegacyQuery | |
| LegacyVisualization |
The visualization description API changes frequently and is unsupported.
|
| ListAlertsRequest |
List alerts
|
| ListAlertsResponse | |
| ListAlertsResponseAlert | |
| ListDashboardsRequest |
Get dashboard objects
|
| ListQueriesLegacyRequest |
Get a list of queries
|
| ListQueriesRequest |
List queries
|
| ListQueriesResponse | |
| ListQueryHistoryRequest |
List Queries
|
| ListQueryObjectsResponse | |
| ListQueryObjectsResponseQuery | |
| ListResponse | |
| ListVisualizationsForQueryRequest |
List visualizations on a query
|
| ListVisualizationsForQueryResponse | |
| ListWarehousesRequest |
List warehouses
|
| ListWarehousesResponse | |
| MultiValuesOptions | |
| NumericValue | |
| OdbcParams | |
| Parameter | |
| QueriesAPI |
The queries API can be used to perform CRUD operations on queries.
|
| QueriesLegacyAPI |
These endpoints are used for CRUD operations on query definitions.
|
| Query | |
| QueryBackedValue | |
| QueryEditContent | |
| QueryFilter | |
| QueryHistoryAPI |
A service responsible for storing and retrieving the list of queries run against SQL endpoints
and serverless compute.
|
| QueryInfo | |
| QueryList | |
| QueryMetrics |
A query metric that encapsulates a set of measurements for a single query.
|
| QueryOptions | |
| QueryParameter | |
| QueryPostContent | |
| QueryVisualizationsAPI |
This is an evolving API that facilitates the addition and removal of visualizations from existing
queries in the Databricks Workspace.
|
| QueryVisualizationsLegacyAPI |
This is an evolving API that facilitates the addition and removal of vizualisations from existing
queries within the Databricks Workspace.
|
| RedashConfigAPI |
Redash V2 service for workspace configurations (internal)
|
| RepeatedEndpointConfPairs | |
| RestoreDashboardRequest |
Restore a dashboard
|
| RestoreQueriesLegacyRequest |
Restore a query
|
| RestoreResponse | |
| ResultData | |
| ResultManifest |
The result manifest provides schema and metadata for the result set.
|
| ResultSchema |
The schema is an ordered list of column descriptions.
|
| ServiceError | |
| SetRequest |
Set object ACL
|
| SetResponse | |
| SetWorkspaceWarehouseConfigRequest | |
| SetWorkspaceWarehouseConfigResponse | |
| StartRequest |
Start a warehouse
|
| StartWarehouseResponse | |
| StatementExecutionAPI |
The Databricks SQL Statement Execution API can be used to execute SQL statements on a SQL
warehouse and fetch the result.
|
| StatementParameterListItem | |
| StatementResponse | |
| StatementStatus |
The status response includes execution state and if relevant, error information.
|
| StopRequest |
Stop a warehouse
|
| StopWarehouseResponse | |
| Success | |
| TerminationReason | |
| TextValue | |
| TimeRange | |
| TransferOwnershipObjectId | |
| TransferOwnershipRequest |
Transfer object ownership
|
| TrashAlertRequest |
Delete an alert
|
| TrashQueryRequest |
Delete a query
|
| UpdateAlertRequest | |
| UpdateAlertRequestAlert | |
| UpdateQueryRequest | |
| UpdateQueryRequestQuery | |
| UpdateResponse | |
| UpdateVisualizationRequest | |
| UpdateVisualizationRequestVisualization | |
| User | |
| Visualization | |
| WarehouseAccessControlRequest | |
| WarehouseAccessControlResponse | |
| WarehousePermission | |
| WarehousePermissions | |
| WarehousePermissionsDescription | |
| WarehousePermissionsRequest | |
| WarehousesAPI |
A SQL warehouse is a compute resource that lets you run SQL commands on data objects within
Databricks SQL.
|
| WarehouseTypePair | |
| Widget | |
| WidgetOptions | |
| WidgetPosition |
Coordinates of this widget on a dashboard.
|
| Enum | Description |
|---|---|
| AlertOperator | |
| AlertOptionsEmptyResultState |
State that alert evaluates to when query result is empty.
|
| AlertState | |
| ChannelName | |
| ColumnInfoTypeName |
The name of the base data type.
|
| CreateWarehouseRequestWarehouseType |
Warehouse type: `PRO` or `CLASSIC`.
|
| DatePrecision | |
| DateRangeValueDynamicDateRange | |
| DateValueDynamicDate | |
| Disposition | |
| EditWarehouseRequestWarehouseType |
Warehouse type: `PRO` or `CLASSIC`.
|
| EndpointInfoWarehouseType |
Warehouse type: `PRO` or `CLASSIC`.
|
| ExecuteStatementRequestOnWaitTimeout |
When `wait_timeout > 0s`, the call will block up to the specified time.
|
| Format | |
| GetWarehouseResponseWarehouseType |
Warehouse type: `PRO` or `CLASSIC`.
|
| GetWorkspaceWarehouseConfigResponseSecurityPolicy |
Security policy for warehouses
|
| LegacyAlertState |
State of the alert.
|
| LifecycleState | |
| ListOrder | |
| ObjectType |
A singular noun object type.
|
| ObjectTypePlural |
Always a plural of the object type.
|
| OwnableObjectType |
The singular form of the type of object which can be owned.
|
| ParameterType |
Parameters can have several different types.
|
| PermissionLevel |
* `CAN_VIEW`: Can view the query * `CAN_RUN`: Can run the query * `CAN_EDIT`: Can edit the query
* `CAN_MANAGE`: Can manage the query
|
| PlansState |
Possible Reasons for which we have not saved plans in the database
|
| QueryStatementType | |
| QueryStatus |
Statuses which are also used by OperationStatus in runtime
|
| RunAsMode | |
| RunAsRole |
Sets the **Run as** role for the object.
|
| ServiceErrorCode | |
| SetWorkspaceWarehouseConfigRequestSecurityPolicy |
Security policy for warehouses
|
| SpotInstancePolicy |
Configurations whether the warehouse should use spot instances.
|
| State |
State of the warehouse
|
| StatementState |
Statement execution state: - `PENDING`: waiting for warehouse - `RUNNING`: running - `SUCCEEDED`:
execution was successful, result data available for fetch - `FAILED`: execution failed; reason
for failure described in accomanying error message - `CANCELED`: user canceled; can come from
explicit cancel call, or timeout with `on_wait_timeout=CANCEL` - `CLOSED`: execution successful,
and statement closed; result no longer available for fetch
|
| Status |
Health status of the warehouse.
|
| SuccessMessage | |
| TerminationReasonCode |
status code indicating why the cluster was terminated
|
| TerminationReasonType |
type of the termination
|
| WarehousePermissionLevel |
Permission level
|
| WarehouseTypePairWarehouseType |
Warehouse type: `PRO` or `CLASSIC`.
|
Copyright © 2025. All rights reserved.